\name{hdpmnPredict}
\alias{hdpmnPredict}
\title{Posterior inference for the dependent random probability measures.}
\description{
  Generates posterior predictive draws for
  future patients (observations) from the random probability measures.
}
\usage{
  hdpmnPredict(
    j = 1, r = 0,
    nsim = 100, 
    npa = NULL, p = NULL, px = NULL,
    idx.x = NULL,
    X = NULL,
    work.dir = NULL, header = T)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{j}{study}
  \item{r}{indicator for including (0) or not (1) the
    common measure.}
  \item{nsim}{Number of imputed posterior simulations to use.}
  \item{p}{number of columns for \code{X}, i.e.,
    dimension of the random effects vector including the
    covariates.}
  \item{px}{Dimension of covariate vector.}
  \item{idx.x}{vector of size \code{px}, columns (starting to count at 1
    for the 1st column) that contain the \code{px} covariates.
    The remaining columns are dummies corresponding to the
    (\code{p}-\code{px})-dimensional response vector.}
  \item{npa}{Number of rows in \code{X}, i.e., number
    of \bf{future} patients for posterior predictive inference.}
  \item{X}{Random effects (dummy values) and covariates
    for future patients, (\code{npa} by \code{p}) matrix.
    \code{X} can be a matrix of a file name.}
  \item{work.dir}{directory to save working files.}
  \item{header}{indicator for a header line in \code{X}}
}
\details{
  Must run \code{\link{hdpmn}} first to generate posterior
  simulations.

  The function carries out post-processing of the MCMC posterior
  simulation to generate posterior predictive simulation for
  future observations from the random probability measures
  defined in the model.
  See   \code{\link{hdpmn-package}}
  for a statement of the probability model.
  
  For \code{npa} assumed future patients with given covariates
  (specified in \code{X}) the
  function computes posterior predictive inference of future
  responses.
  The subvector of responses is a dummy to match the dimension. 
}
\value{
  The function returns a matrix \code{zout} with
  \code{p+1} columns of posterior predictive simulations for the
  \code{npa} future patients.
  The first column is a patient index. An index i refers to the
  i-th row in the matrix \code{X} of given patient covariates.
  Columns 2 through \code{p+1} are posterior predictive simulations
  including the (unchanged) covariate vector in the locations
  indicated by \code{idx}.
  
  Scatterplots, density estimates etc. of the posterior
  predictive simulations can be used to evaluate posterior means for
  the RPMs, and to evaluate posterior predictive probabilities
  for events of interest for future subjects (patients).

  See the examples below for examples on how to summarize
  the posterior predictive simulations.
}
\references
{
   Mueller, P., Quintana, F. and Rosner, G. (2004).
  ``Hierarchical Meta-Analysis over Related Non-parametric Bayesian
  Models.''
  Journal of the Royal Statistical Society, Series B, 66, 735--749.}
\author{Peter Mueller}
\examples{
\dontrun{
###
### hdpm.R - Demo
###

require(hdpmn)

## data files
data.dir <- system.file("data",package="hdpmn")

## data files
Z <- file.path(data.dir,"CALGBz.txt")  
     ## data (first 7 columns) and covariates (last 3 columns)
X <- file.path(data.dir,"CALGBz0.txt")
     ## same as Z, for future patients (for prediction)
S <- file.path(data.dir,"CALGBstudy.txt")
     ## table of patient number and study index
pa.st <- as.matrix(read.table(S,header=T))
study <- pa.st[,2]  # get study index


## run MCMC -- save working files in current working directory
hdpmn(Z=Z,nstudies=3,n.iter=500,study=study,px=3,q=15,cc=15,
      work.dir=work.dir)

## post-process MCMC output for predictive inference
## save posterior predictive simulations in z00 ... z30
z10 <- hdpmnPredict(X=X,px=3,j=1,r=0) # post prediction for study 1
z20 <- hdpmnPredict(X=X,px=3,j=2,r=0) # .. study 2
z30 <- hdpmnPredict(X=X,px=3,j=3,r=0) # .. population at large (= study 3)

z11 <- hdpmnPredict(X=X,px=3,j=1,r=1) # idiosyncratic measures study 1
z21 <- hdpmnPredict(X=X,px=3,j=2,r=1) # .. study 2
z00 <- hdpmnPredict(X=X,px=3,j=0,r=0) # common measure

## covariates (and dummy random effects) of future patients
X <- as.matrix(read.table(X,header=T))
colnames(z00) <- c("PATIENT",colnames(X))

## plot estimated density for future patients in study 1, 2 and
## in population at large
idx <- which(z10[,1]==1)   ## PATIENT 1
options(digits=2)

par(mfrow=c(2,1))          

## plot prediction fo study 1,2,population
plot  (density(z10[idx,8]),
       ylim=c(0,1.5),xlim=c(-0.5,2.5),
       xlab="SLOPE OF RECOVERY",bty="l",main="FUTURE PAT 1")
lines (density(z20[idx,8]),type="l",col=2)
lines (density(z30[idx,8]),type="l",col=3)
legend(-0.5,1.5,col=1:3,legend=c("STUDY 1","STUDY 2","POPULATION"),
       lty=c(1,1,1),bty="n")

## common and idiosyncratic measures
plot (density(z00[idx,8]),type="l",col=4,lty=1,
       ylim=c(0,1.5),xlim=c(-0.5,2.5),
       xlab="SLOPE OF RECOVERY",bty="l",main="COMMON & IDIOSYNC PARTS")
lines (density(z11[idx,8]),type="l",col=1,lty=2)
lines (density(z21[idx,8]),type="l",col=2,lty=2)
legend(1.5,1.5,col=c(1,2,4),lty=c(2,2,1),
       legend=c("STUDY 1 (idiosyn.)",
                "STUDY 2 (idiosyn.)",
                "COMMON"),bty="n")

## plot estimated density for future patients in study 1, 2 and
## in population at large
idx <- which(z10[,1]==2)   ## PATIENT 2
options(digits=2)

par(mfrow=c(2,1))

plot  (density(z10[idx,8]),
       ylim=c(0,1.5),xlim=c(-0.5,2.5),
       xlab="SLOPE OF RECOVERY",bty="l",main="FUTURE PAT 2")
lines (density(z20[idx,8]),type="l",col=2)
lines (density(z30[idx,8]),type="l",col=3)
legend(-0.5,1.5,col=1:3,legend=c("STUDY 1","STUDY 2","POPULATION"),
       lty=c(1,1,1),bty="n")

plot (density(z00[idx,8]),type="l",col=4,lty=1,
       ylim=c(0,1.5),xlim=c(-0.5,2.5),
       xlab="SLOPE OF RECOVERY",bty="l",main="COMMON & IDIOSYNC PARTS")
lines (density(z11[idx,8]),type="l",col=1,lty=2)
lines (density(z21[idx,8]),type="l",col=2,lty=2)
legend(1.5,1.5,col=c(1,2,4),lty=c(2,2,1),
       legend=c("STUDY 1 (idiosyn.)",
                "STUDY 2 (idiosyn.)",
                "COMMON"),bty="n")

## plot nadir count by covariate, for population 
z2 <- z30[,3]; ctx <- z30[,9]; gm <- z30[,10]; amf <- z30[,11]
## fix covariates gm (GM-CSF) and amf (aminofostine)
idx <- which( (gm==-1.78) & (amf== -0.36) )
boxplot(split(z2,ctx),
        xlab="CYCLOPHOSPHAMIDE",bty="n",ylab="NADIR COUNT")
}
}
